# Generated by Django 5.2.7 on 2026-01-22 17:31

import netbox.models.deletion
import taggit.managers
import utilities.json
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("extras", "0133_make_cf_minmax_decimal"),
        ("netbox_snmp", "0002_userprofiles"),
    ]

    operations = [
        migrations.CreateModel(
            name="ViewTrees",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True, null=True)),
                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
                ("custom_field_data", models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder)),
                ("name", models.CharField(max_length=100)),
                ("description", models.CharField(blank=True, max_length=100)),
                ("comments", models.TextField(blank=True)),
                ("view_type", models.CharField(default="included")),
                ("oid", models.CharField(max_length=32)),
                ("tags", taggit.managers.TaggableManager(through="extras.TaggedItem", to="extras.Tag")),
            ],
            options={
                "verbose_name_plural": "Views",
                "ordering": ["name"],
            },
            bases=(netbox.models.deletion.DeleteMixin, models.Model),
        ),
    ]
