# Generated by Django 5.2.7 on 2026-01-22 21:05

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_snmp", "0006_notifyprofiles"),
    ]

    operations = [
        migrations.RenameField(
            model_name="notifyprofiles",
            old_name="_type",
            new_name="noti_type",
        ),
    ]
