# Generated by Django 5.2.7 on 2026-01-22 20:04

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_snmp", "0004_rename_viewtrees_mibtrees"),
    ]

    operations = [
        migrations.AddField(
            model_name="trapprofiles",
            name="user_profile",
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name="trapprofiles", to="netbox_snmp.userprofiles"),
        ),
    ]
