# Generated by Django 5.2.7 on 2026-01-22 18:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('extras', '0133_make_cf_minmax_decimal'),
        ('netbox_snmp', '0003_viewtrees'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='ViewTrees',
            new_name='MibTrees',
        ),
    ]
