# Generated by Django 5.2.7 on 2026-01-22 21:20

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_snmp", "0007_rename__type_notifyprofiles_noti_type"),
    ]

    operations = [
        migrations.RenameField(
            model_name="notifyprofiles",
            old_name="noti_type",
            new_name="notification_type",
        ),
    ]
