from setuptools import find_packages, setup

setup(
    name="netbox-snmp",
    version="0.4.0",
    description="SNMP related data",
    author="AGE Solutions",
    author_email="michael.terrero@age.solutions",
    install_requires=[],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
)
