# Generated by Django 5.2.7 on 2026-01-22 21:24

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_snmp", "0008_rename_noti_type_notifyprofiles_notification_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="mibtrees",
            name="oid",
            field=django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=32), blank=True, default=list, size=None),
        ),
    ]
